/***************************************************************************
 *   copyright            : (C) 1999 by Daniel Reith                       *
 *   email                : DanR@gmx.de                                    *
 *                                                                         *
 *   copyright           : (C) 2003 by Hendrik Sattler                     *
 *   mail                : pingos@hendrik-sattler.de                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef INFO_H
#define INFO_H

#include <wx/wx.h>
#include <wx/textctrl.h>

class MyCanvas: public wxScrolledWindow {
 public:
  MyCanvas(wxWindow *parent, wxBitmap* b,
	   const wxPoint& pos, const wxSize& size);
  ~MyCanvas(void) ;
  void OnPaint(wxPaintEvent& event);
 private:
  wxBitmap* logo; 

 DECLARE_EVENT_TABLE()
};


class Info_Dialog : public wxDialog {
 public:
  Info_Dialog(wxWindow* parent);
  ~Info_Dialog();

 private:
  wxBitmap* logo;
  wxStaticText* message;
  // Added this button to give it the focus during dialog
  // creation:
  wxButton* BtnClose;

 DECLARE_EVENT_TABLE()
};


#endif
